summaryrefslogtreecommitdiff
path: root/chart2/source/controller/main/ChartController.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'chart2/source/controller/main/ChartController.hxx')
-rw-r--r--chart2/source/controller/main/ChartController.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/chart2/source/controller/main/ChartController.hxx b/chart2/source/controller/main/ChartController.hxx
index f2b64eb7a9c5..70a8b7048bea 100644
--- a/chart2/source/controller/main/ChartController.hxx
+++ b/chart2/source/controller/main/ChartController.hxx
@@ -124,7 +124,7 @@ public:
@param rOutEqualRect is filled with a rectangle that denotes the region
in which the quick help does not change.
- @return </TRUE>, if a quick help should be shown.
+ @return </sal_True>, if a quick help should be shown.
*/
virtual bool requestQuickHelp(
::Point aAtLogicPosition, bool bIsBalloonHelp,
@@ -700,7 +700,7 @@ private:
MOVE_OBJECT,
CENTERED_RESIZE_OBJECT
};
/// @return </TRUE>, if resize/move was successful
bool impl_moveOrResizeObject(
const ::rtl::OUString & rCID, eMoveOrResizeType eType, double fAmountLogicX, double fAmountLogicY );
bool impl_DragDataPoint( const ::rtl::OUString & rCID, double fOffset );
@@ -700,7 +700,7 @@ private:
CENTERED_RESIZE_OBJECT
};
- /// @return </TRUE>, if resize/move was successful
+ /// @return </sal_True>, if resize/move was successful
bool impl_moveOrResizeObject(
const ::rtl::OUString & rCID, eMoveOrResizeType eType, double fAmountLogicX, double fAmountLogicY );